pub fn generate(module: &Module, gctx: &GlobalContext) -> Result<String>Expand description
Generate Rust source code from a parsed IR module + global context.
Returns the formatted source as a string, ready to be written to a file.
pub fn generate(module: &Module, gctx: &GlobalContext) -> Result<String>Generate Rust source code from a parsed IR module + global context.
Returns the formatted source as a string, ready to be written to a file.