resolve_module

Function resolve_module 

pub fn resolve_module(specifier: &str, base_dir: &Path) -> Option<PathBuf>
Attempt to resolve a module specifier to a .d.ts file path.

base_dir is the directory containing the file that has the import statement. oxc_resolver finds node_modules automatically by walking up from base_dir.

Returns None if the file can’t be found.