TypeScript type scope tracking with arena-based ownership.
Each scope maps type names to TypeIds — indices into the global type arena.
Scopes form a tree via parent links, enabling JS-like scoping where child
scopes shadow or extend parent scopes.
Scopes are stored in a flat arena (ScopeArena) and referenced by
well-typed ScopeId indices.
Structs
- Pending
Import - An unresolved import that needs to be resolved during import resolution. Stored in a side table on GlobalContext, not in the scope.
- Scope
Arena - Arena that owns all scopes. Scopes are created via
create_rootandcreate_child, and referenced byScopeId. - ScopeId
- Index into a
ScopeArena. Lightweight, Copy, and well-typed. - Type
Scope - A single level of type scope.